@@ -40,8 +40,8 @@ private:
 	
 } // sugar
 
-template <int RTYPE, bool _NA_, typename T>
-inline sugar::SeqLen seq_along( const Rcpp::VectorBase<RTYPE,_NA_,T>& t){
+template <int RTYPE, bool NA, typename T>
+inline sugar::SeqLen seq_along( const Rcpp::VectorBase<RTYPE,NA,T>& t){
 	return sugar::SeqLen( t.size() ) ;
 }
 
