@@ -1,9 +1,10 @@
-// -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; tab-width: 8 -*-
+// -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; tab-width: 4 -*-
 //
 // RcppStringVector.cpp: Rcpp R/C++ interface class library -- string vector support
 //
 // Copyright (C) 2005 - 2006 Dominick Samperi
 // Copyright (C) 2008 - 2009 Dirk Eddelbuettel
+// Copyright (C) 2010	     Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -25,38 +26,38 @@
 RcppStringVector::RcppStringVector(SEXP vec) {
     int i;
     if (Rf_isMatrix(vec) || Rf_isLogical(vec))
-	throw std::range_error("RcppStringVector: invalid numeric vector in constructor");
+		throw std::range_error("RcppStringVector: invalid numeric vector in constructor");
     if (!Rf_isString(vec))
-	throw std::range_error("RcppStringVector: invalid string");
+		throw std::range_error("RcppStringVector: invalid string");
     int len = Rf_length(vec);
     if (len == 0)
-	throw std::range_error("RcppStringVector: null vector in constructor");
-    v = new std::string[len];
+		throw std::range_error("RcppStringVector: null vector in constructor");
     for (i = 0; i < len; i++)
-	v[i] = std::string(CHAR(STRING_ELT(vec,i)));
-    length = len;
+		v.push_back(std::string(CHAR(STRING_ELT(vec,i))));
 }
 
-RcppStringVector::~RcppStringVector() {
-    delete [] v;
+const std::string& RcppStringVector::operator()(int i) const {
+    if (i < 0 || i >= static_cast<int>(v.size())) {
+		std::ostringstream oss;
+		oss << "RcppStringVector: subscript out of range: " << i;
+		throw std::range_error(oss.str());
+    }
+    return v[i];
 }
 
-std::string& RcppStringVector::operator()(int i) const {
-    if (i < 0 || i >= length) {
-	std::ostringstream oss;
-	oss << "RcppStringVector: subscript out of range: " << i;
-	throw std::range_error(oss.str());
+std::string& RcppStringVector::operator()(int i) {
+    if (i < 0 || i >= static_cast<int>(v.size())) {
+		std::ostringstream oss;
+		oss << "RcppStringVector: subscript out of range: " << i;
+		throw std::range_error(oss.str());
     }
     return v[i];
 }
 
 int RcppStringVector::size() const { 
-    return length; 
+    return v.size(); 
 }
 
 std::vector<std::string> RcppStringVector::stlVector() const {
-    std::vector<std::string> tmp(length);
-    for (int i = 0; i < length; i++)
-	tmp[i] = v[i];
-    return tmp;
+    return v;
 }
